###################################################
### chunk number 1: 
###################################################

library(gMCP)
options(width=140)
options(digits=4)
gMCPReport <- function(...) {invisible(NULL)}
graphGUI <- function(...) {invisible(NULL)}



###################################################
### chunk number 2: 
###################################################

graph <- createBonferroniHolmGraph(3)
cat(graph2latex(graph, scale=0.7, fontsize="tiny", labelTikZ="near start,fill=blue!20"))



###################################################
### chunk number 3: 
###################################################

graph <- createBonferroniHolmGraph(3)
cat(graph2latex(graph, scale=0.7, fontsize="tiny", nodeTikZ="minimum size=1.2cm"))
cat("$\\downarrow$ reject $H_1$\\\\")
graph <- rejectNode(graph, "H1")
cat(graph2latex(graph, scale=0.7, fontsize="tiny", nodeTikZ="minimum size=1.2cm"))
cat("$\\downarrow$ reject $H_3$\\\\")
graph <- rejectNode(graph, "H3")
cat(graph2latex(graph, scale=0.7, fontsize="tiny", nodeTikZ="minimum size=1.2cm"))
cat("reject $H_2$")



###################################################
### chunk number 4: 
###################################################

library(gMCP)
graphGUI()



###################################################
### chunk number 5: 
###################################################

library(gMCP)
graph <- createBonferroniHolmGraph(3)
gMCP(graph, pvalues=c(0.01,0.04,0.02), alpha=0.05)



###################################################
### chunk number 6: 
###################################################

hnodes <- c("H11", "H21", "H31", "H12", "H22", "H32")
weights <- c(1/3, 1/3, 1/3, 0, 0, 0)
edges <- list()
edges[["H11"]] <- list(edges=c("H21","H12"), weights=c(1/2, 1/2))
edges[["H21"]] <- list(edges=c("H11","H31","H22"), weights=c(1/3, 1/3, 1/3))
edges[["H31"]] <- list(edges=c("H21","H32"), weights=c(1/2, 1/2))
edges[["H12"]] <- list(edges="H21", weights=1)
edges[["H22"]] <- list(edges=c("H11","H31"), weights=c(1/2, 1/2))
edges[["H32"]] <- list(edges="H21", weights=1)
graph <- new("graphMCP", nodes=hnodes, edgeL=edges, weights=weights)
nodeX <- c(H11=100, H21=300, H31=500, H12=100, H22=300, H32=500)
nodeY <- c(H11=100, H21=100, H31=100, H12=300, H22=300, H32=300)
nodeRenderInfo(graph) <- list(nodeX=nodeX, nodeY=nodeY)	
cat(graph2latex(graph, scale=0.7, fontsize="tiny"))



###################################################
### chunk number 7: 
###################################################

hnodes <- c("H11", "H21", "H31", "H12", "H22", "H32")
weights <- c(1/3, 1/3, 1/3, 0, 0, 0)
edges <- list()
edges[["H11"]] <- list(edges=c("H21","H12"), weights=c(1/2, 1/2))
edges[["H21"]] <- list(edges=c("H11","H31","H22"), weights=c(1/3, 1/3, 1/3))
edges[["H31"]] <- list(edges=c("H21","H32"), weights=c(1/2, 1/2))
edges[["H12"]] <- list(edges="H21", weights=1)
edges[["H22"]] <- list(edges=c("H11","H31"), weights=c(1/2, 1/2))
edges[["H32"]] <- list(edges="H21", weights=1)
graph <- new("graphMCP", nodes=hnodes, edgeL=edges, weights=weights)



###################################################
### chunk number 8: 
###################################################

print(graph)



###################################################
### chunk number 9: 
###################################################

nodeX <- c(H11=100, H21=300, H31=500, H12=100, H22=300, H32=500)
nodeY <- c(H11=100, H21=100, H31=100, H12=300, H22=300, H32=300)
nodeRenderInfo(graph) <- list(nodeX=nodeX, nodeY=nodeY)	



###################################################
### chunk number 10: 
###################################################

cat(graph2latex(graph))



###################################################
### chunk number 11: 
###################################################

edgeData(graph, "H11", "H21", "labelX") <- 200
edgeData(graph, "H11", "H21", "labelY") <- 80



###################################################
### chunk number 12: 
###################################################

# Bonferroni-Holm:
m <- matrix(rep(1/3, 16), nrow=4)
diag(m) <- c(0, 0, 0, 0)
graph <- matrix2graph(m)
print(graph)
graph2matrix(graph)



###################################################
### chunk number 13: 
###################################################

graphGUI("graph")



###################################################
### chunk number 14: 
###################################################

graph <- createGraphFromBretzEtAl()

# We can reject a single node:
print(rejectNode(graph, "H11"))

# Or given a vector of pvalues let the function gMCP do all the work:  
pvalues <- c(0.1, 0.008, 0.005, 0.15, 0.04, 0.006)
result <- gMCP(graph, pvalues)
print(result)



###################################################
### chunk number 15: 
###################################################

cat(graph2latex(result@graphs[[4]], scale=0.7, fontsize="tiny"))



###################################################
### chunk number 16: 
###################################################

gMCPReport(result, "Report.tex")



###################################################
### chunk number 17: 
###################################################

pval <- c(0.02,0.055,0.012)

df <- 9
# Sample Standard Deviations:
s <- c(1.2, 0.8, 1.7)
# Statistics:
st <- qt(pval/2,df=df, lower.tail=FALSE)
# Estimates:
est <- st*s/sqrt(10)



###################################################
### chunk number 18: 
###################################################

# Estimates:
est <- c("H1"=0.9101444, "H2"=0.4485153, "H3"=1.4568271)
# Sample standard deviations:
ssd <- c("H1"=1.2, "H2"=0.8, "H3"=1.7)

simConfint(createBonferroniHolmGraph(3),
		pvalues  = c(0.02,0.055,0.012), 
		confint = function(node, alpha) {
			est[node]+c(-1,1)*qt(1-alpha/2,df=9)*ssd[node]/sqrt(10)
		})



###################################################
### chunk number 19: 
###################################################

cat(graph2latex(createGraphForParallelGatekeeping(), scale=0.7, fontsize="tiny", nodeTikZ="minimum size=1.2cm", tikzEnv=FALSE))
cat(graph2latex(createGraphForImprovedParallelGatekeeping(), scale=0.7, fontsize="tiny", nodeTikZ="minimum size=1.2cm", tikzEnv=FALSE, offset=c(300, 0)))



###################################################
### chunk number 20: 
###################################################

graph <- createGraphForImprovedParallelGatekeeping()
graph
substituteEps(graph, eps=0.001)

gMCP(graph, pvalues=c(0.02, 0.04, 0.01, 0.02), eps=0.001)



###################################################
### chunk number 21: 
###################################################

cat(graph2latex(result@graphs[[3]], pvalues=pvalues, scale=0.7, fontsize="tiny"))



